.. _spkg_sagemath_pari_seadata_small:

=====================================================================================================
sagemath_pari_seadata_small: Computational Number Theory with PARI/GP: seadata_small
=====================================================================================================


This pip-installable distribution ``passagemath-pari-seadata-small`` is a
distribution of data for use with ``passagemath-pari``.


What is included
----------------

- Wheels on PyPI include the seadata_small files


Type
----

standard


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_pari_seadata_small`
- :ref:`spkg_sage_conf`
- :ref:`spkg_sage_setup`
- :ref:`spkg_sagemath_environment`
- :ref:`spkg_setuptools`

Version Information
-------------------

package-version.txt::

    10.6.13

version_requirements.txt::

    passagemath-pari-seadata-small ~= 10.6.13.0

Equivalent System Packages
--------------------------

(none known)
